<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>Website Under Construction</title>
  <style>
  *, :after, :before {
    box-sizing: border-box;
    border: 0 solid #e5e7eb;
  }
  body {
    margin: 0;
    font-family: system-ui,-apple-system,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;
    background-color: #fbfbfb;
    color: #222;
    display: flex;
    align-items: center;
    justify-content: center;
    height: 100vh;
    text-align: center;
  }
  h1 {
    font-weight: bolder;
    font-size: 34px;
    text-transform: uppercase;
  }
  p {
    font-size: 18px;
  }
  </style>
</head>
<body>
  <div>
    <h1>
      🛠️ Comming Soon
    </h1>
    <p>
      Website is currently under construction
    </p>
  </div>
</body>
</html>
